Nothing

Struct Nothing 

pub struct Nothing;
An empty syntax tree node that consumes no tokens when parsed.

This is useful for attribute macros that want to ensure they are not provided any attribute args.

use proc_macro::TokenStream;
use syn::parse_macro_input;
use syn::parse::Nothing;

#[proc_macro_attribute]
pub fn my_attr(args: TokenStream, input: TokenStream) -> TokenStream {
    parse_macro_input!(args as Nothing);

    /* ... */
}
error: unexpected token
 --> src/main.rs:3:19
  |
3 | #[my_attr(asdf)]
  |           ^^^^