NestedMeta

Enum NestedMeta 

pub enum NestedMeta {
    Meta(Meta),
    Lit(Lit),
}
Element of a compile-time attribute list.

This type is available only if Syn is built with the "derive" or "full" feature.

Variants



Meta(Meta)

A structured meta item, like the Copy in #[derive(Copy)] which would be a nested Meta::Path.



Lit(Lit)

A Rust literal, like the "new_name" in #[rename("new_name")].